雪煙チェイス - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# 雪煙チェイス

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/%E9%9B%AA%E7%85%99%E3%83%81%E3%82%A7%E3%82%A4%E3%82%B9/Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/%E9%9B%AA%E7%85%99%E3%83%81%E3%82%A7%E3%82%A4%E3%82%B9/Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.60 KiB | 06 Jan 2026 09:37:30
2 | Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.74 KiB | 06 Jan 2026 09:37:30

Nothing to show.

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/%E9%9B%AA%E7%85%99%E3%83%81%E3%82%A7%E3%82%A4%E3%82%B9/Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/%E9%9B%AA%E7%85%99%E3%83%81%E3%82%A7%E3%82%A4%E3%82%B9/Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.60 KiB | 06 Jan 2026 09:37:30
2 | Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.74 KiB | 06 Jan 2026 09:37:30

Upload new files — Search MDL — Back to Index